@@ -25,18 +25,22 @@ help_cont[8] = 'yinyang  : Draw the TaiJi.'
 help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
 
 def Help(page=1,lines = 5):
-    maxPage = int((0.5+len(help_cont))/lines)+1
+    if type(page) != int or type(lines) != int:
+        return print('Please input interger.')
+    if page == 0:
+        return Help(1,10000)
+    maxPage = ceil(len(help_cont)/lines)#int((0.5+len(help_cont))/lines)+1
     if (page - 1) * lines >= len(help_cont):
         print(f'Page Error, check the number : [{1},{maxPage}]')
         return
-    print(f"{'=-'*14}= H E L P {'=-'*14}=\n")
+    print(colored(f"{'=-'*14}= ",'yellow')+"H E L P"+colored(f" {'=-'*14}=\n",'yellow'))
     for i in range(lines):
         try:
             n = i+lines*(page-1)
             ll = colored(f"{help_cont[n]}",'green')
             print(f'   {n} - '+ll)
         except:break
-    print(f"\n{'=-'*14} page({page}/{maxPage}) {'-='*14}")
+    print('\n'+colored(f"{'=-'*14}= ",'yellow')+f"page({page}/{maxPage})"+colored(f" {'=-'*14}=",'yellow'))
     if page < maxPage:print(colored(f'\t\t\thelp({page+1}) for next page','green'))
 
 
@@ -150,7 +154,7 @@ def prove(cont):
     
 def getLogo():
     print(colored(LOGO.randlogo(),choice(['red','yellow','green'])))
-    
+    print(__verion__)
 
 def yinyang():
     import f61d.yinyang
